@@ -28,8 +28,8 @@ libreoffice-draw
 libreoffice-impress
 libreoffice-math
 libreoffice-writer
-libreoffice-l10n-za
-libreoffice-gtk2
+libreoffice-l10n-xh
+libreoffice-gtk3
 </install_package_names>
 
 <postinstall>
@@ -42,8 +42,8 @@ libreoffice-draw
 libreoffice-impress
 libreoffice-math
 libreoffice-writer
-libreoffice-l10n-za
-libreoffice-gtk2
+libreoffice-l10n-xh
+libreoffice-gtk3
 </uninstall_package_names>
 
 </app>
